BtxFeatureFlagsState class

Annotations

Constructors

BtxFeatureFlagsState({Map<String, bool> values = const <String, bool>{}, int? revision, DateTime? evaluatedAt, bool loaded = false})
factory
BtxFeatureFlagsState.unloaded()
const

Properties

evaluatedAt DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
loaded bool
final
revision int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, bool>
final

Methods

isEnabled(String key, {bool fallback = false}) bool
Returns the evaluated value for key, or fallback when unavailable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override