BtxForegroundNotification class

Constructors

BtxForegroundNotification({required String id, required String threadId, required String messageId, required String title, required String body, required DateTime createdAt})
const

Properties

body String
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
messageId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threadId String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited