BtxImageInput class

Constructors

BtxImageInput({required String id, required Uint8List bytes, required String mimeType, required String filename, int? width, int? height})
const

Properties

bytes Uint8List
final
filename String
final
hashCode int
The hash code for this object.
no setterinherited
height int?
final
id String
final
mimeType String
final
optimisticAttachment BtxAttachment
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited