Singleton BTX Flutter SDK facade.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
debugStateListenable
→ ValueListenable<
Object> -
no setter
- featureFlags → BtxFeatureFlagsState
-
Current feature-flag snapshot.
no setter
-
featureFlagsListenable
→ ValueListenable<
BtxFeatureFlagsState> -
Observable feature-flag snapshot for the active identity.
no setter
- knowledgeBase → BtxKnowledgeBaseFacade
-
Knowledge base namespace for presentation and article actions.
final
- messenger → BtxMessengerFacade
-
Messenger namespace for presentation and thread actions.
final
- push → BtxPushFacade
-
Push namespace for host-provided Android source binding and cleanup.
final
- status → BtxCustomerSdkStatus
-
Current telemetry runtime status.
no setter
-
statusListenable
→ ValueListenable<
BtxCustomerSdkStatus> -
Observable telemetry runtime status.
no setter
Static Methods
-
configure(
BtxConfiguration configuration) → Future< void> - Configures the SDK runtime.
-
dispose(
) → Future< void> - Disposes SDK-owned runtime state.
-
featureFlagEnabled(
String key, {bool fallback = false, bool refresh = false}) → Future< bool> - Returns a feature flag value after pending configure/identity work settles.
-
flush(
{Duration? timeout}) → Future< void> - Flushes pending telemetry.
-
identify(
BtxCustomer? customer) → Future< void> - Updates the active customer identity.
-
isFeatureEnabled(
String key, {bool fallback = false}) → bool - Returns a feature flag value from the current snapshot.
-
log(
String eventType, {BtxLogLevel level = BtxLogLevel.info, String? message, Map< String, Object?> properties = const <String, Object?>{}, DateTime? occurredAt}) → Future<void> - Records a structured app log with explicit severity.
-
ready(
) → Future< void> - Completes when all pending SDK configure/identity work has settled.
-
refreshFeatureFlags(
) → Future< BtxFeatureFlagsState> - Refreshes feature flags for the active identity.
Constants
- sdkName → const String
- Name reported in automatically captured BTX app context.
- sdkVersion → const String
- Package version reported in automatically captured BTX app context.